﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using PCBI.Automation;
using System.IO;

namespace Demo2WindowsFormsApplicationCSharp
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            ActivateAllSignalLayers();
        }

        /// <summary>
        /// Activate all signal layers from the current step of given PCBI-Embedded-Design.
        /// </summary>
        private void ActivateAllSignalLayers()
        {
            IAutomation.IAutomationInit();

            IPCBIWindow mainWindowPCBI;

            if (File.Exists(@"D:\tests\PCB-Investigator-Design.exe"))
                //create a window to handle your actions
                mainWindowPCBI = IAutomation.OpenEmbeddedDesign(@"D:\tests\PCB-Investigator-Design.exe", false);
            else
            {
                OpenFileDialog openDLG = new OpenFileDialog();
                openDLG.FileName = @"D:\tests\PCB-Investigator-Design.exe";
                openDLG.Title = "Please select PCB-Investigator Embedded Design";
                if (openDLG.ShowDialog() != System.Windows.Forms.DialogResult.OK)
                    return;
                mainWindowPCBI = IAutomation.OpenEmbeddedDesign(openDLG.FileName, false);
            }
            //we use the first step and work only with this one
            IStep currentStep = mainWindowPCBI.GetCurrentStep();

            //the matirx contains all important informations of the job
            IMatrix matrix = mainWindowPCBI.GetMatrix();
            if (matrix == null || currentStep == null)
            {
                MessageBox.Show("The Demo stops, because no Embedded Design was selected.", "No Job Found", MessageBoxButtons.OK, MessageBoxIcon.Information);
                return;
            }
            //show the loaded embedded design with active signal layers
            mainWindowPCBI.Show();

            foreach (string layername in matrix.GetAllLayerNames())
            {
                //only board layer of interest
                if (matrix.GetMatrixLayerContext(layername) != MatrixLayerContext.Board)
                    continue;

                //only signal layers
                if (matrix.GetMatrixLayerType(layername) != MatrixLayerType.Signal)
                    continue;

                //load the layer
                ILayer layerSignal = currentStep.GetLayer(layername);

                //activate the layer
                layerSignal.EnableLayer(true);
            }

            //at the end its important to update view, then PCB-Investigator draws the elements to grahic pane
            mainWindowPCBI.UpdateView();
        }
    }
}
